export default {
    "index": 28,
    "lineNumber": 1,
    "column": 29,
    "message": "The keyword 'yield' is reserved"
};
